/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.ant.tasks;

import java.io.File;
import java.io.IOException;
import org.apache.tools.ant.BuildException;
import org.apache.tools.ant.Task;
import com.openexchange.osgi.data.BinDirModule;
import com.openexchange.osgi.data.DirModule;
import com.openexchange.osgi.data.JarModule;

/**
 * Sets if a bundle is a host or a fragment.
 * 
 * @author <a href="mailto:martin.schneider@open-xchange.com">Martin Schneider</a>
 * @since 7.4
 */
public class IsFragment extends Task {

    private String propertyName;
    private String bundle;

    public IsFragment() {
        super();
    }

    public void setPropertyName(String propertyName) {
        this.propertyName = propertyName;
    }

    public void setBundle(String bundle) {
        this.bundle = bundle;
    }

    @Override
    public void execute() throws BuildException {
        if (null == propertyName) {
            throw new BuildException("Please define property that should be set.");
        }
        if (null == bundle) {
            throw new BuildException("Please define name of bundle file to read.");
        }
        File classpathFile = new File(bundle);
        if (!classpathFile.exists()) {
            throw new BuildException("Unable to read bundle: \"" + classpathFile.getAbsolutePath() + "\".");
        }
        boolean isFragment = false;
        if (classpathFile.isFile()) {
            JarModule jarModule;
            try {
                jarModule = new JarModule(classpathFile);
            } catch (IOException e) {
                throw new BuildException(e.getMessage(), e);
            }
            isFragment = jarModule.isFragment();
        } else {
            DirModule classpathModule = new BinDirModule(classpathFile);
            try {
                classpathModule.readLocalFiles();
            } catch (IOException e) {
                throw new BuildException(e.getMessage(), e);
            }
            isFragment = classpathModule.isFragment();
        }
        getProject().setInheritedProperty(propertyName, Boolean.toString(isFragment));
    }
}
